summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetewalletmanager.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-08-27 23:21:05 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-08-27 23:21:05 -0500
commitcce87d87ca74d317dd4102d64ff0a8e784f539a2 (patch)
treea4c7ce926dc52a9b36769b2b1551f9a5861b72b6 /kopete/libkopete/kopetewalletmanager.h
parent01fd5fb452ff67b8c31853c9a3bf181a74d44883 (diff)
downloadtdenetwork-cce87d87ca74d317dd4102d64ff0a8e784f539a2.tar.gz
tdenetwork-cce87d87ca74d317dd4102d64ff0a8e784f539a2.zip
Rename KWallet to TDEWallet
Diffstat (limited to 'kopete/libkopete/kopetewalletmanager.h')
-rw-r--r--kopete/libkopete/kopetewalletmanager.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kopete/libkopete/kopetewalletmanager.h b/kopete/libkopete/kopetewalletmanager.h
index f12f826c..eef2d24b 100644
--- a/kopete/libkopete/kopetewalletmanager.h
+++ b/kopete/libkopete/kopetewalletmanager.h
@@ -23,7 +23,7 @@
#include "kopete_export.h"
-namespace KWallet { class Wallet; }
+namespace TDEWallet { class Wallet; }
namespace Kopete
{
@@ -32,7 +32,7 @@ namespace Kopete
* @author Richard Smith <kde@metafoo.co.uk>
*
* The Kopete::WalletManager class is a singleton, which looks after Kopete's
- * KWallet connection.
+ * TDEWallet connection.
*/
class KOPETE_EXPORT WalletManager : public TQObject
{
@@ -47,11 +47,11 @@ public:
~WalletManager();
/**
* @brief Attempt to open the KWallet asyncronously, then signal an
* object to indicate the task is complete.
*
* @param object The object to call back to
* @param slot The slot on object to call; must have signature slot( KWallet::Wallet* )
* The parameter to the slot will be the wallet that was opened if the call
* succeeded, or NULL if the wallet failed to open or the Kopete folder was
* inaccessible.
@@ -90,7 +90,7 @@ private slots:
private:
void openWalletInner();
- void emitWalletOpened( KWallet::Wallet *wallet );
+ void emitWalletOpened( TDEWallet::Wallet *wallet );
class Private;
Private *d;
@@ -109,7 +109,7 @@ class KopeteWalletSignal : public TQObject
friend class Kopete::WalletManager;
signals:
- void walletOpened( KWallet::Wallet *wallet );
+ void walletOpened( TDEWallet::Wallet *wallet );
};
#endif
@@ -47,11 +47,11 @@ public:
~WalletManager();
/**
- * @brief Attempt to open the KWallet asyncronously, then signal an
+ * @brief Attempt to open the TDEWallet asyncronously, then signal an
* object to indicate the task is complete.
*
@@ -47,11 +47,11 @@ public:
*
* @param object The object to call back to
- * @param slot The slot on object to call; must have signature slot( KWallet::Wallet* )
+ * @param slot The slot on object to call; must have signature slot( TDEWallet::Wallet* )
* The parameter to the slot will be the wallet that was opened if the call
* succeeded, or NULL if the wallet failed to open or the Kopete folder was